<?php

/**
 *
 */
class Modula_Advanced_Shortcodes {

	/**
	 * Holds the class object.
	 *
	 * @since 1.0.0
	 *
	 * @var object
	 */
	public static $instance;

	/**
	 * The name of the plugin.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	public $plugin_name = 'Modula Advanced Shortcodes';

	/**
	 * Unique plugin slug identifier.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	public $plugin_slug = 'modula-advanced-shortcodes';

	/**
	 * Primary class constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Load the plugin textdomain.
		add_action( 'plugins_loaded', array( $this, 'load_plugin_textdomain' ) );
		add_shortcode( 'modula_all_galleries', array( $this, 'modula_all_galleries' ) );
		add_shortcode( 'modula_filters', array( $this, 'modula_output_filters' ) );

		// Load the plugin.
		$this->init();

	}

	/**
	 * Loads the plugin textdomain for translation.
	 *
	 * @since 1.0.0
	 */
	public function load_plugin_textdomain() {
		load_plugin_textdomain( $this->plugin_slug, false, MODULA_ADVANCED_SHORTCODES_PATH . '/languages/' );
	}

	/**
	 * Loads the plugin into WordPress.
	 *
	 * @since 1.0.0
	 */
	public function init() {

		// Load admin only components.
		if ( is_admin() ) {
			add_action( 'modula_pro_updater', array( $this, 'addon_updater' ), 15, 2 );
		}

	}

	public function addon_updater( $license_key, $store_url ) {

		if ( class_exists( 'Modula_Pro_Base_Updater' ) ) {
			$modula_addon_updater = new Modula_Pro_Base_Updater( $store_url, MODULA_ADVANCED_SHORTCODES_FILE,
				array(
					'version' => MODULA_ADVANCED_SHORTCODES_VERSION,        // current version number
					'license' => $license_key,               // license key (used get_option above to retrieve from DB)
					'item_id' => 3555,                      // ID of the product
					'author'  => 'MachoThemes',            // author of this plugin
					'beta'    => false,
				)
			);
		}
	}

	/**
	 * Returns the singleton instance of the class.
	 *
	 * @since 1.0.0
	 *
	 * @return object The Advanced_Shortcodes object.
	 */
	public static function get_instance() {

		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Modula_Advanced_Shortcodes ) ) {
			self::$instance = new Modula_Advanced_Shortcodes();
		}

		return self::$instance;

	}

	/**
	 * Shortcode for displaying all galleries or galleries based on gallery_id request
	 */
	public function modula_all_galleries() {

		$output = '';

		if ( isset( $_REQUEST['gallery_id'] ) ) {
			$gallery_id   = intval($_REQUEST['gallery_id']);

			$gallery_args = array(
				'post_type' => 'modula-gallery',
				'post__in'  => array( $gallery_id ),
				'order'     => 'DESC'
			);
			$galleries    = new WP_Query( $gallery_args );

			if ( 0 == $galleries->found_posts ) {
				return __('No galleries found matching id','modula-advanced-shortcodes').' <strong>'.esc_html($gallery_id).'</strong>';
			}

		} else {
			$gallery_args = array(
				'post_type'      => 'modula-gallery',
				'posts_per_page' => - 1,
				'orderby'        => 'menu_order',
				'order'          => 'DESC'
			);

			$galleries = new WP_Query( $gallery_args );
		}

		if ( $galleries->have_posts() ) {
			while ( $galleries->have_posts() ) {
				$galleries->the_post();
				$id = get_the_ID();
				if ( ! is_admin() ) {
					$output.= do_shortcode( '[modula id="' . esc_attr($id) . '"]' );
				}
			}
			wp_reset_postdata();
		}

		return $output;
	}

	/**
	 * Shortcode to output only the filters
	 */

	public function modula_output_filters(){
		$filters_array = array();
		$gallery_args = array(
			'post_type'      => 'modula-gallery',
			'posts_per_page' => - 1,
			'orderby'        => 'menu_order',
			'order'          => 'DESC'
		);
		$galleries = new WP_Query( $gallery_args );
		if ( $galleries->have_posts() ) {
			while ( $galleries->have_posts() ) {
				$galleries->the_post();
				$modula_settings = get_post_meta(get_the_ID(),'modula-settings',true);
				$filters = $modula_settings['filters'];
				if($filters){
					foreach($filters as $filter){
						if(! in_array($filter,$filters_array)){
							$filters_array[] = $filter;
						}
					}

				}
			}
			wp_reset_postdata();
		}

		$html = '<div class="modula modula-gallery"><div class="filters">';
		$html .= '<a data-filter="all" href="#" class="selected">All</a>';

		foreach($filters_array as $filter){
			$html .= '<a class="" data-filter="'.esc_attr($filter).'" href="#jtg-filter-'.esc_html($filter).'">'.esc_html($filter).'</a>';
		}

		$html .= '</div></div>';

		return $html;

	}


}