<?php

class Modula_SpeedUp_Setings {

	/**
     * Holds the admin class object.
     *
     * @since 1.0.0
     *
     * @var object
     */
    public static $instance;
	
	function __construct() {

		// Filter Modula Fields
		add_filter( 'modula_gallery_fields', array( $this, 'modula_speedup_fields' ) );

		// Filter Modula Gallery
		add_filter( 'modula_gallery_tabs', array( $this, 'add_speedup_gallery' ) );

		// Filter Defaults
		add_filter( 'modula_lite_default_settings', array( $this, 'default_settings' ) );

		// Render Field Type
		add_filter( 'modula_render_speedup-select_field_type', array( $this, 'render_field_type' ), 10, 3 );

		// Stop resize if we have speed up enabled
		add_filter( 'modula_resize_images', array( $this, 'check_if_optimize' ), 10, 2 );

		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ), 15 );

		// Add Setings Tab
		add_filter( 'modula_admin_page_tabs', array( $this, 'add_compression_tab' ) );
		add_action( 'modula_admin_tab_compression', array( $this, 'render_compression_tab' ) );
		add_action( 'admin_init', array( $this, 'register_compression_option' ) );

	}

	/**
     * Returns the singleton instance of the class.
     *
     * @since 1.0.0
     *
     * @return object The Modula_Video_Setings object.
     */
    public static function get_instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Modula_SpeedUp_Setings ) ) {
            self::$instance = new Modula_SpeedUp_Setings();
        }

        return self::$instance;

    }

    /* Enqueue Admin Scripts */
	public function admin_scripts( $hook ) {

		global $id, $post;

        // Get current screen.
        $screen = get_current_screen();

        // Check if is modula custom post type
        if ( 'modula-gallery' !== $screen->post_type ) {
            return;
        }

        // Set the post_id
        $post_id = isset( $post->ID ) ? $post->ID : (int) $id;

		if ( 'post-new.php' == $hook || 'post.php' == $hook ) {

			wp_enqueue_style( 'modula-speedup', MODULA_SPEEDUP_URL . 'assets/css/admin.css' );

			wp_enqueue_script( 'modula-speedup', MODULA_SPEEDUP_URL . 'assets/js/admin.js', array( 'jquery', 'jquery-ui-sortable' ), '2.0.0', true );

		}

	}

    public function add_speedup_gallery( $tabs ){

    	if ( isset( $tabs['speedup'] ) ) {
    		return $tabs;
    	}

    	$tabs['speedup'] = array(
    		'label'       => esc_html__( 'Speed Up', 'modula-speedup' ),
			'title'       => esc_html__( 'Optimize your images', 'modula-speedup' ),
			"icon"        => "dashicons dashicons-dashboard",
			'priority'    => 75,
    	);

    	return $tabs;
    }

	/**
     * Add video related settings.
     *
     * @since 1.0.0
     *
     * @return array $fields.
     */
	public function modula_speedup_fields(  $fields ){
		$fields['speedup'] = array(
			'enable_optimization' => array(
				"name"        => esc_html__( 'Compression', 'modula-gallery' ),
				"type"        => "speedup-select",
				'default'     => 'default',
				"values"      => array(
					'default'  => esc_html__( 'Default', 'modula-speedup' ),
					'enabled'  => esc_html__( 'Enabled', 'modula-speedup' ),
					'disabled' => esc_html__( 'Disabled', 'modula-speedup' ),
				),
				"description" => esc_html__( 'Adjust this setting to enable image optimization.', 'modula-speedup' ),
				'priority'    => 1,
			),
			"thumbnail_optimization" => array(
				"name"        => esc_html__( 'Thumbnail Compression', 'modula-speedup' ),
				"type"        => "speedup-select",
				"description" => esc_html__( 'Choose the compression level for your gallery’s image thumbnails', 'modula-speedup' ),
				'default'     => 'default',
				"values"      => array(
					'default'  => esc_html__( 'Default', 'modula-speedup' ),
					'lossless' => esc_html__( 'Lossless Compresion', 'modula-speedup' ),
					'lossy'    => esc_html__( 'Lossy Compresion', 'modula-speedup' ),
					'glossy'   => esc_html__( 'Glossy Compresion', 'modula-speedup' ),
					'disabled' => esc_html__( 'Disable Compresion', 'modula-speedup' ),
				),
				'priority' => 5,
			),
			"lightbox_optimization" => array(
				"name"        => esc_html__( 'Lightbox Compression', 'modula-speedup' ),
				"type"        => "speedup-select",
				"description" => esc_html__( 'Choose the compression level for your gallery’s images when opened in your chosen lightbox.', 'modula-speedup' ),
				'default'     => 'default',
				"values"      => array(
					'default'  => esc_html__( 'Default', 'modula-speedup' ),
					'lossless' => esc_html__( 'Lossless Compresion', 'modula-speedup' ),
					'lossy'    => esc_html__( 'Lossy Compresion', 'modula-speedup' ),
					'glossy'   => esc_html__( 'Glossy Compresion', 'modula-speedup' ),
					'disabled' => esc_html__( 'Disable Compresion', 'modula-speedup' ),
				),
				'priority' => 10,
			),
			"modula_speed_help" => array(
				"name"     => '',
				"type"     => "content",
				"content"  => $this->compression_description(),
				'priority' => 15,
			),
		);

		return $fields;

	}

	/**
     * Add default for item's video url.
     *
     * @since 1.0.0
     *
     * @return array $defaults.
     */
	public function default_settings( $defaults ){

		$defaults['enable-optimization']    = 'default';
		$defaults['thumbnail_optimization'] = 'default';
		$defaults['lightbox_optimization']  = 'default';

		return $defaults;

	}

	public function compression_description(){

		$description = '<span class="dashicons dashicons-warning"></span> ';
		$description .= sprintf( esc_html__( 'When set to *default* the Modula default gallery optimization settings you have chosen under %sModula > Settings%s will be used.', 'modula-speedup' ), '<a target="_blank" href="' . admin_url( 'edit.php?post_type=modula-gallery&page=modula&modula-tab=compression' ) . '">', '</a>' );
		$description .= '<br><br>';
		$description .= sprintf( '<strong>%s</strong>. %s', esc_html__( 'Lossless Compression', 'modula-speedup' ), esc_html__( 'File sizes will be reduced by removing unnecessary image information (and statistical redundancies) resulting in no loss in quality.', 'modula-speedup' ) );
		$description .= '<br><br>';
		$description .= sprintf( '<strong>%s</strong>. %s', esc_html__( 'Lossy Compression', 'modula-speedup' ), esc_html__( 'File sizes will be reduced significantly resulting in a slight loss in image quality that is visible. Choose this option if you want your website to load as fast as possible.', 'modula-speedup' ) );
		$description .= '<br><br>';
		$description .= sprintf( '<strong>%s</strong>. %s', esc_html__( 'Glossy Compression', 'modula-speedup' ), esc_html__( 'Glossy is the best choice if you care about your website’s load time and believe that a slight loss in page speed is an acceptable compromise for top-notch image quality.', 'modula-speedup' ) );
		$description .= '<br>';

		return $description;

	}

	public function add_compression_tab( $tabs ){
		$tabs['compression'] = array(
			'label'    => esc_html__( 'Compression Settings', 'modula-speedup' ),
			'priority' => 10,
		);

		return $tabs;
	}

	public function render_compression_tab() {
		include 'tabs/compression.php';
	}

	public function register_compression_option() {
		// creates our settings in the options table
		register_setting('modula_speedup', 'modula_speedup', array( $this, 'sanitize_option' ) );
	}

	public function sanitize_option( $current ) {
		$defaults = array(
			'enable_optimization'    => 'disabled',
			'thumbnail_optimization' => 'lossy',
			'lightbox_optimization'  => 'lossless',
		);

		$accepted_values = array( 'lossless', 'lossy', 'glossy', 'disabled' );
		$new = array();

		if ( isset( $current['enable_optimization'] ) ) {
			$new['enable_optimization'] = 'enabled';
		}else{
			$new['enable_optimization'] = 'disabled';
		}

		if ( isset( $current['thumbnail_optimization'] ) && in_array( $current['thumbnail_optimization'], $accepted_values ) ) {
			$new['thumbnail_optimization'] = $current['thumbnail_optimization'];
		}

		if ( isset( $current['lightbox_optimization'] ) && in_array( $current['lightbox_optimization'], $accepted_values ) ) {
			$new['lightbox_optimization'] = $current['lightbox_optimization'];
		}

		$new = wp_parse_args( $new, $defaults );

		return $new;
	}

	public function render_field_type( $html, $field, $value ){

		$defaults = get_option( 'modula_speedup', array(
            'enable_optimization'    => 'disabled',
            'thumbnail_optimization' => 'lossy',
            'lightbox_optimization'  => 'lossless',
        ) );

		$html = '<select name="modula-settings[' . esc_attr( $field['id'] ) . ']" data-setting="' . esc_attr( $field['id'] ) . '" class="regular-text speedup-select">';
		foreach ( $field['values'] as $key => $option ) {
			if ( is_array( $option ) ) {
				$html .= '<optgroup label="' . esc_attr( $key ) . '">';
				foreach ( $option as $key_subvalue => $subvalue ) {
					$html .= '<option value="' . esc_attr( $key_subvalue ) . '" ' . selected( $key_subvalue, $value, false ) . '>' . esc_html( $subvalue ) . '</option>';
				}
				$html .= '</optgroup>';
			}else{
				$html .= '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $value, false ) . '>' . esc_html( $option ) . '</option>';
			}
		}
		$html .= '</select>';

		$style = '';
		if ( 'default' != $value ) {
			$style = 'display:none';
		}

		$html .= '<span class="extra-info" style="' . $style . '">Default Status: <strong>' . $defaults[ $field['id'] ] . '</strong></span>';

		return $html;
	}

	public function check_if_optimize( $status, $settings ){

		if ( ! isset( $settings['enable_optimization'] ) ) {
			return $status;
		}

		$defaults = get_option( 'modula_speedup', array(
            'enable_optimization'    => 'disabled',
            'thumbnail_optimization' => 'lossy',
            'lightbox_optimization'  => 'lossless',
        ) );

        if ( ( 'default' == $settings['enable_optimization'] && 'enabled' == $defaults['enable_optimization'] ) || 'enabled' == $settings['enable_optimization'] ) {
        	return false;
        }

        return $status;

	}

}

// Load the main plugin class.
$modula_speedup_settings = Modula_SpeedUp_Setings::get_instance();