<?php

$speedup_settings = get_option( 'modula_speedup', array(
	'enable_optimization'    => 'disabled',
	'thumbnail_optimization' => 'lossy',
	'lightbox_optimization'  => 'lossless',
) );

$values = array(
	'lossless' => esc_html__( 'Lossless Compresion', 'modula-speedup' ),
	'lossy'    => esc_html__( 'Lossy Compresion', 'modula-speedup' ),
	'glossy'   => esc_html__( 'Glossy Compresion', 'modula-speedup' ),
	'disabled' => esc_html__( 'Disable Compresion', 'modula-speedup' ),
);


?>
<style type="text/css">
	/* Toggles */
	.modula-toggle {
	    position: relative;
	    position: relative;
	    user-select: none;
	    display: inline-block;
	}

	.modula-toggle__items {
	  box-sizing: border-box;
	  display: inline-block;
	    position: relative;
	}
	.modula-toggle__items > * {
	  box-sizing: inherit;
	}

	.modula-toggle__input[type=checkbox] {
	  border-radius: 2px;
	  border: 2px solid #6c7781;
	  margin-right: 12px;
	  transition: none;
	  height: 100%;
	  left: 0;
	  top: 0;
	  margin: 0;
	  padding: 0;
	  opacity: 0;
	  position: absolute;
	  width: 100%;
	  z-index: 1; }

	.modula-toggle__track {
	  background-color: #fff;
	  border: 2px solid #6c7781;
	  border-radius: 9px;
	  display: inline-block;
	  height: 18px;
	  width: 36px;
	  vertical-align: top;
	  transition: background .2s ease; }

	.modula-toggle__thumb {
	  background-color: #6c7781;
	  border: 5px solid #6c7781;
	  border-radius: 50%;
	  display: block;
	  height: 10px;
	  width: 10px;
	  position: absolute;
	  left: 4px;
	  top: 4px;
	  transition: transform .2s ease; }

	.modula-toggle__off {
	  position: absolute;
	  right: 6px;
	  top: 6px;
	  color: #6c7781;
	  fill: currentColor; }

	.modula-toggle__on {
	  position: absolute;
	  top: 6px;
	  left: 8px;
	  border: 1px solid #fff;
	  outline: 1px solid transparent;
	  outline-offset: -1px;
	  display: none; }

	.modula-toggle__input[type=checkbox]:checked + .modula-toggle__items .modula-toggle__track {
	  background-color: #11a0d2;
	  border: 9px solid transparent; }

	.modula-toggle__input[type=checkbox]:checked + .modula-toggle__items .modula-toggle__thumb {
	  background-color: #fff;
	  border-width: 0;
	  transform: translateX(18px); }

	.modula-toggle__input[type=checkbox]:checked + .modula-toggle__items .modula-toggle__off {
	  display: none; }

	.modula-toggle__input[type=checkbox]:checked + .modula-toggle__items .modula-toggle__on {
	  display: inline-block; }
</style>
<div class="row">
	<form method="post" action="options.php">

		<?php settings_fields('modula_speedup'); ?>

		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top">
						<?php _e('Compression', 'modula'); ?>
					</th>
					<td>
						<div class="modula-toggle">
							<input id="modula_speedup_optimization" class="modula-toggle__input" type="checkbox" <?php checked( 'enabled', $speedup_settings['enable_optimization'], true ); ?> name="modula_speedup[enable_optimization]" value="enabled">
							<div class="modula-toggle__items">
								<span class="modula-toggle__track"></span>
								<span class="modula-toggle__thumb"></span>
								<svg class="modula-toggle__off" width="6" height="6" aria-hidden="true" role="img" focusable="false" viewBox="0 0 6 6"><path d="M3 1.5c.8 0 1.5.7 1.5 1.5S3.8 4.5 3 4.5 1.5 3.8 1.5 3 2.2 1.5 3 1.5M3 0C1.3 0 0 1.3 0 3s1.3 3 3 3 3-1.3 3-3-1.3-3-3-3z"></path></svg>
								<svg class="modula-toggle__on" width="2" height="6" aria-hidden="true" role="img" focusable="false" viewBox="0 0 2 6"><path d="M0 0h2v6H0z"></path></svg>
							</div>
							<!-- <label for="modula_speedup_optimization"></label> -->
						</div>
						<p class="description">
							<?php esc_html_e( 'Toggle this in order to enable/disable the compression of the images', 'modula-speedup' ) ?>
						</p>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">
						<?php _e('Thumbnail Compression', 'modula-speedup'); ?>
					</th>
					<td>
						<select name="modula_speedup[thumbnail_optimization]">
							<?php
							foreach ( $values as $value => $label ) {
								echo '<option value="' . $value . '" ' . selected( $value, $speedup_settings['thumbnail_optimization'], false ) . '>' . $label . '</option>';
							}
							?>
						</select>
						<p class="description">
							<?php esc_html_e( 'Choose the compression level for your gallery’s image thumbnails', 'modula-speedup' ) ?>
						</p>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">
						<?php _e('Lightbox Compression', 'modula-speedup'); ?>
					</th>
					<td>
						<select name="modula_speedup[lightbox_optimization]">
							<?php
							foreach ( $values as $value => $label ) {
								echo '<option value="' . $value . '" ' . selected( $value, $speedup_settings['lightbox_optimization'], false ) . '>' . $label . '</option>';
							}
							?>
						</select>
						<p class="description">
							<?php esc_html_e( 'Choose the compression level for your gallery’s images when opened in your chosen lightbox.', 'modula-speedup' ) ?>
						</p>
					</td>
				</tr>
			</tbody>
		</table>
		<div>
			<?php
			echo '<p>' . sprintf( '<strong>%s</strong>. %s', esc_html__( 'Lossless Compression', 'modula-speedup' ), esc_html__( 'File sizes will be reduced by removing unnecessary image information (and statistical redundancies) resulting in no loss in quality.', 'modula-speedup' ) ) . '</p>';
			echo '<p>' . sprintf( '<strong>%s</strong>. %s', esc_html__( 'Lossy Compression', 'modula-speedup' ), esc_html__( 'File sizes will be reduced significantly resulting in a slight loss in image quality that is visible. Choose this option if you want your website to load as fast as possible.', 'modula-speedup' ) ) . '</p>';
			echo '<p>' . sprintf( '<strong>%s</strong>. %s', esc_html__( 'Glossy Compression', 'modula-speedup' ), esc_html__( 'Glossy is the best choice if you care about your website’s load time and believe that a slight loss in page speed is an acceptable compromise for top-notch image quality.', 'modula-speedup' ) ) . '</p>';
			?>
		</div>
		<?php submit_button(); ?>
	</form>
</div>