<?php

/**
 * 
 */
class Modula_SpeedUp {

	/**
     * Holds the class object.
     *
     * @since 1.0.0
     *
     * @var object
     */
    public static $instance;

    /**
     * The name of the plugin.
     *
     * @since 1.0.0
     *
     * @var string
     */
    public $plugin_name = 'Modula Speed Up';

    /**
     * Unique plugin slug identifier.
     *
     * @since 1.0.0
     *
     * @var string
     */
    public $plugin_slug = 'modula-speedup';

    private $imgopt_host = 'https://modula.shortpixel.ai/';
    private $site_host;
    private $settings;
	
	/**
     * Primary class constructor.
     *
     * @since 1.0.0
     */
    public function __construct() {

        // Get website domain
        if ( function_exists( 'domain_mapping_siteurl' ) ) {
            $this->site_host = domain_mapping_siteurl( get_current_blog_id() );
        } else {
            $this->site_host = site_url();
        }

        // Load the plugin textdomain.
        add_action( 'plugins_loaded', array( $this, 'load_plugin_textdomain' ) );

        if ( is_admin() ) {
            add_action( 'modula_pro_updater', array( $this, 'addon_updater' ), 15, 2 );
            $this->require_admin();
        }

        add_filter( 'modula_lite_default_settings', array( $this, 'speedup_defaults') );
        add_filter( 'modula_shortcode_item_data', array( $this, 'generate_optimized_image_links'), 5, 3  );

        $this->settings = get_option( 'modula_speedup', array(
            'enable_optimization'    => 'disabled',
            'thumbnail_optimization' => 'lossy',
            'lightbox_optimization'  => 'lossless',
        ) );

    }

    /**
     * Loads the plugin textdomain for translation.
     *
     * @since 1.0.0
     */
    public function load_plugin_textdomain() {
        load_plugin_textdomain( $this->plugin_slug, false, MODULA_SPEEDUP_PATH . '/languages/' );
    }

    public function addon_updater( $license_key, $store_url ){

        if ( class_exists( 'Modula_Pro_Base_Updater' ) ) {
            $modula_addon_updater = new Modula_Pro_Base_Updater( $store_url, MODULA_SPEEDUP_FILE,
                array(
                    'version' => MODULA_SPEEDUP_VERSION,        // current version number
                    'license' => $license_key,               // license key (used get_option above to retrieve from DB)
                    'item_id' => 3555,                      // ID of the product
                    'author'  => 'MachoThemes',            // author of this plugin
                    'beta'    => false,
                )
            );
        }
    }

    /**
     * Loads all admin related files into scope.
     *
     * @since 1.0.0
     */
    public function require_admin() {

        require_once MODULA_SPEEDUP_PATH . 'includes/admin/class-modula-speedup-settings.php';

    }

    /**
     * Returns the singleton instance of the class.
     *
     * @since 1.0.0
     *
     * @return object The Modula_Video object.
     */
    public static function get_instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Modula_SpeedUp ) ) {
            self::$instance = new Modula_SpeedUp();
        }

        return self::$instance;

    }

    public function generate_optimized_image_links( $item_data, $item, $settings ) {

        if ( 'disabled' == $settings['enable_optimization'] ) {
            return $item_data;
        }

        if ( 'default' == $settings['enable_optimization'] && 'disabled' == $this->settings['enable_optimization'] ) {
            return $item_data;
        }

        $image_compresion = ( 'default' == $settings['thumbnail_optimization'] ) ? $this->settings['thumbnail_optimization'] : $settings['thumbnail_optimization'];
        $lightbox_compresion = ( 'default' == $settings['lightbox_optimization'] ) ? $this->settings['lightbox_optimization'] : $settings['lightbox_optimization'];

        if ( 'disabled' == $image_compresion && 'disabled' == $lightbox_compresion ) {
            return $item_data;
        }

        // Remove previous filter
        remove_filter( 'modula_shortcode_item_data', 'modula_generate_image_links', 10, 3 );

        $gallery_type = isset( $settings['type'] ) ? $settings['type'] : 'creative-gallery';
        $grid_sizes = array(
            'width' => isset( $item['width'] ) ? $item['width'] : 1,
            'height' => isset( $item['height'] ) ? $item['height'] : 1,
        );

        $sizes = $this->get_image_size( $item['id'], $settings['img_size'], $gallery_type, $grid_sizes );

        $image_full = $sizes['url'];

        if ( 'disabled' != $image_compresion ) {
            if ( 0 !== strpos( $sizes['url'], $this->site_host ) ) {
                $image_url = $image_full;
            } else {
                $image_url = $this->build_imgopt_url( $image_full, $sizes['width'], $sizes['height'], $image_compresion );
            }
        }else{
            $image_url = $image_full;
        }

        if ( 'disabled' != $lightbox_compresion ) {
            if ( 0 === strpos( $sizes['url'], $this->site_host ) ) {
                $image_full = $this->build_imgopt_url( $image_full, 0, 0, $lightbox_compresion );
            }
        }

        $item_data['image_full'] = $image_full;
        $item_data['image_url']  = $image_url;

        // Add src/data-src attributes to img tag
        $item_data['img_attributes']['src'] = $image_url;
        $item_data['img_attributes']['data-src'] = $image_url;

        return $item_data;

    }

    public function get_image_size( $id, $img_size, $type = 'creative-gallery', $sizes = array() ) {

        $image_full = wp_get_attachment_image_src( $id, 'full' );

        if ( $image_full ) {

            $return = array(
                'url' => $image_full[0],
            );

            switch ( $type ) {
                case 'creative-gallery':
                    if ( $image_full[1] > $image_full[2] ) {
                        $return['width'] = $img_size;
                        $return['height'] = 0;
                    }else{
                        $return['width'] = 0;
                        $return['height'] = $img_size;
                    }
                    return $return;
                    break;
                case 'custom-grid':
                    $return['width'] = absint( $img_size ) * absint( $sizes['width'] );
                    $return['height'] = absint( $img_size ) * absint( $sizes['height'] );
                    return $return;
                    break;
                default:
                    $return = apply_filters( "modula_resize_image_{$type}", $return, $id, $img_size, $sizes );
                    return $return;
                    break;
            }

        }else{
            return new WP_Error( 'modula-gallery-error-no-url', esc_html__( 'No image with this ID.', 'modula-speedup' ) );
        }

    }

    private function build_imgopt_url( $orig_url, $width = 0, $height = 0, $compression = 'lossless' ) {
        // sanitize width and height.
        if ( strpos( $width, '%' ) !== false ) {
            $width = 0;
        }
        if ( strpos( $height, '%' ) !== false ) {
            $height = 0;
        }
        $width  = (int) $width;
        $height = (int) $height;

        $imgopt_base_url = $this->get_imgopt_base_url( $compression );
        $imgopt_size     = '';
        if ( $width && 0 !== $width ) {
            $imgopt_size = ',w_' . $width;
        }
        if ( $height && 0 !== $height ) {
            $imgopt_size .= ',h_' . $height;
        }
        $url = $imgopt_base_url . $imgopt_size . '/' . $orig_url;
        return $url;
    }

    private function get_imgopt_base_url( $compression ) {

        $imgopt_host     = $this->imgopt_host;
        $imgopt_base_url = $imgopt_host . 'client/q_' . $compression . ',ret_img';
        
        return $imgopt_base_url;
    }

    public function speedup_defaults( $defaults ){

        $defaults['enable_optimization']    = 'default';
        $defaults['thumbnail_optimization'] = 'default';
        $defaults['lightbox_optimization']  = 'default';

        return $defaults;
    }

}