<?php

class Modula_Video_Setings {

	/**
     * Holds the admin class object.
     *
     * @since 1.0.0
     *
     * @var object
     */
    public static $instance;
	
	function __construct() {

		// Filter Modula Fields
		add_filter( 'modula_gallery_fields', array( $this, 'modula_video_fields' ) );

		// Filter Defaults
		add_filter( 'modula_lite_default_settings', array( $this, 'default_settings' ) );

		// Save Filters for our items
		add_filter( 'modula_gallery_image_attributes', array( $this, 'add_item_fields' ) );

		/* Add templates for our plugin */
		add_action( 'admin_footer', array( $this, 'print_modula_video_templates' ) );

		// Add new input for item
		add_action( 'modula_item_extra_fields', array( $this, 'extra_item_fields' ) );

		// Add JS
		add_action( 'modula_scripts_before_wp_modula', array( $this, 'video_js' ) );

	}

	/**
     * Returns the singleton instance of the class.
     *
     * @since 1.0.0
     *
     * @return object The Modula_Video_Setings object.
     */
    public static function get_instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Modula_Video_Setings ) ) {
            self::$instance = new Modula_Video_Setings();
        }

        return self::$instance;

    }

	/**
     * Add video related settings.
     *
     * @since 1.0.0
     *
     * @return array $fields.
     */
	public function modula_video_fields(  $fields ){
		$fields['video'] = array(
			"show-video-icon" => array(
				"name"        => esc_html__( 'Display Play Icon', 'modula-gallery' ),
				"type"        => "toggle",
				"default"     => 1,
				"description" => esc_html__( 'Display a Play Icon over a Gallery Image which is linked to a Video, to make it clear to the user that it is a video.', 'modula-gallery' ),
				'priority'    => 1,
			),
			"video-icon-color"     => array(
				"name"        => esc_html__( 'Play Icon color', 'modula-gallery' ),
				"type"        => "color",
				"default"     => "#ffffff",
				'priority'    => 10,
			),
		);

		return $fields;

	}

	/**
     * Add default for item's video url.
     *
     * @since 1.0.0
     *
     * @return array $defaults.
     */
	public function default_settings( $defaults ){

		$defaults['video_url'] = '';

		return $defaults;

	}

	/**
     * Modula Item's video url template.
     *
     * @since 1.0.0
     *
     */
	public function print_modula_video_templates() {
		?>
		<script type="text/html" id="tmpl-modula-video">
		    <label class="">
                <span class="name"><?php _e( 'Video URL', 'modula-video' ); ?></span>
                <input type="text" name="video_url" value="{{ data.video_url }}" />
                <div class="description">
                    <?php _e( 'Insert a video url, can be YouTube, Vimeo or self hosted.', 'modula-video' ); ?>
                </div>
            </label>
		</script>
		<?php
	}

	/**
     * Item's video url hidden input.
     *
     * @since 1.0.0
     *
     */
	public function extra_item_fields() {
		echo '<input type="hidden" name="modula-images[video_url][{{data.index}}]" class="modula-image-video-url" value="{{ data.video_url }}">';
	}

	/**
     * Add video related settings to edit modal.
     *
     * @since 1.0.0
     *
     * @return array $fields.
     */
	public function add_item_fields( $fields ) {

		$fields[] = 'video_url';
		return $fields;

	}

	/**
     * Add script that will handle video related actions in backend.
     *
     * @since 1.0.0
     *
     */
	public function video_js() {
		wp_enqueue_script( 'modula-video', MODULA_VIDEO_URL . 'assets/js/wp-modula-video.js', array( 'jquery' ), '1.0.0', true );
	}

}

// Load the main plugin class.
$modula_video_settings = Modula_Video_Setings::get_instance();