<?php

/**
 * 
 */
class Modula_Video {

	/**
     * Holds the class object.
     *
     * @since 1.0.0
     *
     * @var object
     */
    public static $instance;

    /**
     * The name of the plugin.
     *
     * @since 1.0.0
     *
     * @var string
     */
    public $plugin_name = 'Modula Video';

    /**
     * Unique plugin slug identifier.
     *
     * @since 1.0.0
     *
     * @var string
     */
    public $plugin_slug = 'modula-video';
	
	/**
     * Primary class constructor.
     *
     * @since 1.0.0
     */
    public function __construct() {

        // Load the plugin textdomain.
        add_action( 'plugins_loaded', array( $this, 'load_plugin_textdomain' ) );

        // Load the plugin.
        $this->init();

    }

    /**
     * Loads the plugin textdomain for translation.
     *
     * @since 1.0.0
     */
    public function load_plugin_textdomain() {
        load_plugin_textdomain( $this->plugin_slug, false, MODULA_VIDEO_PATH . '/languages/' );
    }

    /**
     * Loads the plugin into WordPress.
     *
     * @since 1.0.0
     */
    public function init() {

        // Load admin only components.
        if ( is_admin() ) {
            add_action( 'modula_pro_updater', array( $this, 'addon_updater' ), 15, 2 );
            $this->require_admin();
        }

        add_filter( 'modula_shortcode_item_data', array( $this, 'add_video' ), 80, 3 );
        add_filter( 'modula_get_icon', array( $this, 'show_video_icon' ), 10, 2 );

        add_action( 'modula_item_after_image', array( $this, 'output_video_icon' ) );

        // Register & enqueue scripts for lightbox video
        add_action( 'wp_enqueue_scripts', array( $this, 'register_lightgallery_video_script' ) );
        add_action( 'modula_lighbox_shortcode', array( $this, 'enqueue_lightgallery_video_script' ), 11 );

        // Add video css
        add_filter( 'modula_shortcode_css', array( $this, 'generate_video_css' ), 15, 3 );

    }

    public function addon_updater( $license_key, $store_url ){

        if ( class_exists( 'Modula_Pro_Base_Updater' ) ) {
            $modula_addon_updater = new Modula_Pro_Base_Updater( $store_url, MODULA_VIDEO_FILE,
                array(
                    'version' => MODULA_VIDEO_VERSION,        // current version number
                    'license' => $license_key,               // license key (used get_option above to retrieve from DB)
                    'item_id' => 3555,                      // ID of the product
                    'author'  => 'MachoThemes',            // author of this plugin
                    'beta'    => false,
                )
            );
        }
    }

    /**
     * Loads all admin related files into scope.
     *
     * @since 1.0.0
     */
    public function require_admin() {

        require_once MODULA_VIDEO_PATH . 'includes/admin/class-modula-video-settings.php';

    }

    /**
     * Returns the singleton instance of the class.
     *
     * @since 1.0.0
     *
     * @return object The Modula_Video object.
     */
    public static function get_instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Modula_Video ) ) {
            self::$instance = new Modula_Video();
        }

        return self::$instance;

    }

    /**
     * Alter the current gallery item data in order to add video related attributes.
     *
     * @since 1.0.0
     *
     * @return array item_data.
     */
    public function add_video( $item_data, $item, $settings ) {

    	$item_data['is_video'] = false;

        if ( isset( $settings['show-video-icon'] ) && ! $settings['show-video-icon'] ) {
            return $item_data;
        }

    	if ( isset( $item['video_url'] ) && '' != $item['video_url'] ) {
    		$item_data['link_attributes']['href'] = esc_url( $item['video_url'] );

            if ( 'magnific' == $settings['lightbox'] ) {
                $item_data['link_classes'][] = 'mfp-iframe';
            }

    		$item_data['is_video'] = true;
    	}

    	return $item_data;

    }

    /**
     * Alter the modula icons.
     *
     * @since 1.0.0
     *
     * @return string $svg.
     */
    public function show_video_icon( $svg , $icon ) {

    	if ( 'video' == $icon ) {
    		return '<svg aria-hidden="true" data-prefix="far" data-icon="play-circle" class="svg-inline--fa fa-play-circle fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="#fff" d="M371.7 238l-176-107c-15.8-8.8-35.7 2.5-35.7 21v208c0 18.4 19.8 29.8 35.7 21l176-101c16.4-9.1 16.4-32.8 0-42zM504 256C504 119 393 8 256 8S8 119 8 256s111 248 248 248 248-111 248-248zm-448 0c0-110.5 89.5-200 200-200s200 89.5 200 200-89.5 200-200 200S56 366.5 56 256z"></path></svg>';
    	}

    	return $svg;
    }

    /**
     * Output video icon, if enabled, for each gallery item.
     *
     * @since 1.0.0
     *
     */
    public function output_video_icon( $data ) {

    	if ( $data->is_video ) {
    		echo '<div class="modula-video-icon" style="position: absolute;width: 30px;top: 50%;left: 50%;transform: translate(-50%,-50%);">' . Modula_Helper::get_icon( 'video' ) . '</div>';
    	}

    }

    /**
     * Register lightgallery video script.
     *
     * @since 1.0.0
     *
     */
    public function register_lightgallery_video_script() {
        wp_register_script( 'lightgallery-video', MODULA_VIDEO_URL . 'assets/js/lg-video.min.js', array( 'jquery' ), null, true );
    }

    /**
     * If the current lightbox is lightgallery enqueue the lightgallery video script.
     *
     * @since 1.0.0
     *
     */
    public function enqueue_lightgallery_video_script( $lightbox ) {

        if ( 'lightgallery' == $lightbox ) {
            wp_enqueue_script( 'lightgallery-video' );
        }

    }

    /**
     * Change video icon color if necessary
     *
     * @since 1.0.0
     *
     * @return string $css.
     */
    public function generate_video_css( $css, $gallery_id, $settings ) {

        if ( isset( $settings['show-video-icon'] ) && $settings['show-video-icon'] ) {
           
            if ( isset( $settings['video-icon-color'] ) && '#ffffff' != $settings['video-icon-color'] ) {
                $css .= '#{$gallery_id} .item .modula-video-icon svg path { fill : ' . sanitize_hex_color( $settings['video-icon-color'] ) . ' }';
            }

        }

        return $css;

    }

}